<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ToggleGrid</name>
    <message>
        <location filename="../ToggleGrid.js" line="+90"/>
        <source>&amp;Grid</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Siatka
Ciągłe linie &amp;siatki</translatorcomment>
        <translation>&amp;Siatka</translation>
    </message>
</context>
</TS>
